@@ -1,5 +1,5 @@
 /*
-   mod_ruid2 0.9.5
+   mod_ruid2 0.9.6
    Copyright (C) 2009-2012 Monshouwer Internet Diensten
 
    Author: Kees Monshouwer
@@ -48,7 +48,7 @@
 #include <sys/capability.h>
 
 #define MODULE_NAME		"mod_ruid2"
-#define MODULE_VERSION		"0.9.5"
+#define MODULE_VERSION		"0.9.6"
 
 #define RUID_MIN_UID		100
 #define RUID_MIN_GID		100
@@ -165,8 +165,8 @@ static void *create_config (apr_pool_t *p, server_rec *s)
 {
 	ruid_config_t *conf = apr_palloc (p, sizeof (*conf));
 
-	conf->default_uid=ap_unixd_config.group_id;
-	conf->default_gid=ap_unixd_config.user_id;
+	conf->default_uid=ap_unixd_config.user_id;
+	conf->default_gid=ap_unixd_config.group_id;
 	conf->min_uid=RUID_MIN_UID;
 	conf->min_gid=RUID_MIN_GID;
 	conf->chroot_dir=NULL;
@@ -289,7 +289,7 @@ static const char *set_documentchroot (cmd_parms *cmd, void *mconfig, const char
 /* configure options in httpd.conf */
 static const command_rec ruid_cmds[] = {
 
-	AP_INIT_TAKE1 ("RMode", set_mode, NULL, RSRC_CONF | ACCESS_CONF, "stat or config (default stat)"),
+	AP_INIT_TAKE1 ("RMode", set_mode, NULL, RSRC_CONF | ACCESS_CONF, "Set mode to config or stat (default: config)"),
 	AP_INIT_TAKE2 ("RUidGid", set_uidgid, NULL, RSRC_CONF | ACCESS_CONF, "Minimal uid or gid file/dir, else set[ug]id to default (User,Group)"),
 	AP_INIT_ITERATE ("RGroups", set_groups, NULL, RSRC_CONF | ACCESS_CONF, "Set aditional groups"),
 	AP_INIT_TAKE2 ("RDefaultUidGid", set_defuidgid, NULL, RSRC_CONF, "If uid or gid is < than RMinUidGid set[ug]id to this uid gid"),
